# Covid Data Dashboard

## Introduction

This project is a Covid Data dashbord that outputs up to date covid data and outputs the latest News Articles, it also can schedule updates and is a fully interactive dashboard.

### Prerequisites

this project can be run in any version of python 3 but the ideal is **Python 3.8.1**

### Installation

installation required: **py -m pip install --upgrade build, py -m pip install flask**

### How to use the project

In side the folder src you will find the folder package with all the files needed to run the dashboard for every module and each function in each,
module there is clear instructions on how the function works and how to use it.

### Data Required

For the project you will need to include various thing to the **config.json** file so it works such as:

- **Api Key**
- **Location for the covid data**
- **Search Terms for the News Articles**

### Testing/Running

To test the code before running it there will be various test modules inside the file directory **tests**.
To run the code run **covid_user_interface.py** and search **"http://127.0.0.1:5000/"** in any browser

## Details

Project Created by **Luis Hidalgo Gutierrez De Tovar**,
Licence in file: **LICENSE.txt**
source code in **"index.html"** file
acknoledgments to Module Leader **Matt Collison** for the template ""index.html""
